==> realestate-supervise-common-1.1.0-20241231.014802-54-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdjyq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import cn.gtmap.realestate.supervise.core.reflect.ssywh;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @Date: 2023/12/29 9:07
 * @Description: 土地经营权登记信息（耕地等农用地）
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdjyq"
)
public class BaTdjyq implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @ywh
    private String ywh;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String qdfs;

    @XmlAttribute
    private String cbfdmfbfdm;

    @XmlAttribute
    private String cbfdbfbfqc;

    @XmlAttribute
    private String tdlzmj;

    @XmlAttribute
    private Date lzqssj;

    @XmlAttribute
    private Date lzjssj;

    @XmlAttribute
    private String lzqx;

    @XmlAttribute
    private String lzjg;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String htdm;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String qlxz;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getQdfs() {
        return qdfs;
    }

    public void setQdfs(String qdfs) {
        this.qdfs = qdfs;
    }

    public String getCbfdmfbfdm() {
        return cbfdmfbfdm;
    }

    public void setCbfdmfbfdm(String cbfdmfbfdm) {
        this.cbfdmfbfdm = cbfdmfbfdm;
    }

    public String getCbfdbfbfqc() {
        return cbfdbfbfqc;
    }

    public void setCbfdbfbfqc(String cbfdbfbfqc) {
        this.cbfdbfbfqc = cbfdbfbfqc;
    }

    public String getTdlzmj() {
        return tdlzmj;
    }

    public void setTdlzmj(String tdlzmj) {
        this.tdlzmj = tdlzmj;
    }

    public Date getLzqssj() {
        return lzqssj;
    }

    public void setLzqssj(Date lzqssj) {
        this.lzqssj = lzqssj;
    }

    public Date getLzjssj() {
        return lzjssj;
    }

    public void setLzjssj(Date lzjssj) {
        this.lzjssj = lzjssj;
    }

    public String getLzqx() {
        return lzqx;
    }

    public void setLzqx(String lzqx) {
        this.lzqx = lzqx;
    }

    public String getLzjg() {
        return lzjg;
    }

    public void setLzjg(String lzjg) {
        this.lzjg = lzjg;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getHtdm() {
        return htdm;
    }

    public void setHtdm(String htdm) {
        this.htdm = htdm;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdjyq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.sqlx;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import cn.gtmap.realestate.supervise.core.reflect.ssywh;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @Date: 2023/12/29 9:07
 * @Description: 土地经营权登记信息（耕地等农用地）
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdjyq"
)
public class BaTdjyq implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @ywh
    private String ywh;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String qdfs;

    @XmlAttribute
    private String cbfdmfbfdm;

    @XmlAttribute
    private String cbfdbfbfqc;

    @XmlAttribute
    private String tdlzmj;

    @XmlAttribute
    private Date lzqssj;

    @XmlAttribute
    private Date lzjssj;

    @XmlAttribute
    private String lzqx;

    @XmlAttribute
    private String lzjg;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String htdm;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String qlxz;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getQdfs() {
        return qdfs;
    }

    public void setQdfs(String qdfs) {
        this.qdfs = qdfs;
    }

    public String getCbfdmfbfdm() {
        return cbfdmfbfdm;
    }

    public void setCbfdmfbfdm(String cbfdmfbfdm) {
        this.cbfdmfbfdm = cbfdmfbfdm;
    }

    public String getCbfdbfbfqc() {
        return cbfdbfbfqc;
    }

    public void setCbfdbfbfqc(String cbfdbfbfqc) {
        this.cbfdbfbfqc = cbfdbfbfqc;
    }

    public String getTdlzmj() {
        return tdlzmj;
    }

    public void setTdlzmj(String tdlzmj) {
        this.tdlzmj = tdlzmj;
    }

    public Date getLzqssj() {
        return lzqssj;
    }

    public void setLzqssj(Date lzqssj) {
        this.lzqssj = lzqssj;
    }

    public Date getLzjssj() {
        return lzjssj;
    }

    public void setLzjssj(Date lzjssj) {
        this.lzjssj = lzjssj;
    }

    public String getLzqx() {
        return lzqx;
    }

    public void setLzqx(String lzqx) {
        this.lzqx = lzqx;
    }

    public String getLzjg() {
        return lzjg;
    }

    public void setLzjg(String lzjg) {
        this.lzjg = lzjg;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getHtdm() {
        return htdm;
    }

    public void setHtdm(String htdm) {
        this.htdm = htdm;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }
}
